<?php
include_once('class.errHandler.php');

class Database_mssql extends errHandler
{
	var $db_type	= DB_MSSQL;
	var $db_data;					// data from get_db_list() function
	var $name		= '';
	var $host		= 'localhost';
	var	$connection	= false;

	function Database_mssql($db_name)
	{
		if (empty($db_name)) {
			$this->setError_('Database name is empty.');
			return;
		}

		$this->name = $db_name;

		include_once('cmd_server.php3');
		$db_list =& get_db_list();
		$this->db_data = $db_list[$this->db_type];

		/// Check for DATABASE is installed
		include_once('class.ComponentsChecker.php');

		$components_checker = new ComponentsChecker();
		if ($components_checker->error()) {
			$this->setError_('ComponentsChecker() constructor failed: ' . $components_checker->getErrorMsg());
			return false;
		}

		$isInstalled = $components_checker->isPackageInstalled($this->db_type);
		if ($components_checker->error()) {
			$this->setError_('isPackageInstalled() failed: ' . $components_checker->getErrorMsg());
			return false;
		}
		if (!$isInstalled) {
			$this->setError_(lmsg('__database_not_installed', $this->db_data['name']));
			return false;
		}

		/// Check for DATABASE is runnig
		include_once('class.ServiceControl.php');
		$service =& ServiceControlMaker();

		$isRunning = $service->getServiceStatus($this->db_type);
		if ($service->error()) {
			$this->setError_('getServiceStatus() failed: ' . $service->getErrorMsg());
			return false;
		}
		if (!$isRunning) {
			$this->setError_(lmsg('__database_not_run', $this->db_data['name']));
			return false;
		}

		if (!$this->connect_()) {
			$err_str = $this->getErrorMsg();
			if (LOGIN_FAILED != $err_str)
				$this->setError_('Unable to connect to database: ' . $err_str);

			return false;
		}

		return;
	}

	function connect_()
	{
		if (false != $this->connection)
			return $this->connection;

		$login	= get_param($this->db_type . DB_ADMIN_LOGIN_SUFFIX);
		$passwd	= get_param($this->db_type . DB_ADMIN_PASSWD_SUFFIX);

		if (empty($login)) {
			$this->setError_(lmsg('__database_not_activated', $this->db_data['name']));
			return false;
		}

		///	Local connection
		$this->connection = mssql_connect($this->host, $login, $passwd);
		if (!$this->connection) {
			$err_str = $this->get_db_error();
			$err_str = (strstr($err_str, 'Login failed for user')) ? LOGIN_FAILED : 'Unable to connect to ' . $this->db_data['name'] . ' database: ' . $err_str;
			$this->setError_($err_str);
			return false;
		}

		if (!mssql_select_db('master', $this->connection)) {
			$this->setError_('select db failed: ' . $this->get_db_error());
			return false;
		}

		return true;
	}

	function changePassword($login, $old_passwd, $passwd)
	{
		// just change the password
		$query = "exec master.dbo.sp_password '$old_passwd', '$passwd', '$login'";
		$res = mssql_query($query);
		if (!$res)
			psaerror('Unable to query: ' . $this->get_db_error());

		return true;
	}


	function create()
	{
		if ($this->dbExistance($this->name)) {
			$this->setError_(lmsg('__db_already_exist', $this->name));
			return false;
		}

		$res = mssql_query('CREATE DATABASE ' . $this->name);
		if (!$res)
			psaerror('Unable to query: ' . $this->get_db_error());

		return true;
	}

	function remove()
	{
		$res = mssql_query('DROP DATABASE ' . $this->name);
		if (!$res)
			psaerror('Unable to query: ' . $this->get_db_error());

		return true;
	}

	function userAdd($login, $pass)
	{
		if ($this->userExistance($login)) {
			$this->setError_(lmsg('__user_already_exist', $login));
			return false;
		}

		$query = "exec master.dbo.sp_addlogin '$login', '$pass', '". $this->name . "'";
		$res = mssql_query($query);
		if (!$res)
			psaerror('Unable to query: ' . $this->get_db_error());

		$query = "exec " . $this->name . ".dbo.sp_grantdbaccess '$login'";
		$res = mssql_query($query);
		if (!$res)
			psaerror('Unable to query: ' . $this->get_db_error());

		$query = "exec " . $this->name . ".dbo.sp_addrolemember 'db_owner', '$login'";
		$res = mssql_query($query);
		if (!$res)
			psaerror('Unable to query: ' . $this->get_db_error());

		return true;
	}

	/**
	 *	Parameters - 3 arrays:
	 *	$logins = array($old_login => $new_login);
	 *	$pass
	 */
	function userMod(&$logins, $pass)
	{
		if (!(list($old_login, $new_login) = each($logins)))
			psaerror('Unable to get user variables.');

		/// login changed - check if new user already exists in MSSQL db
		if ($new_login == $old_login) {

			// just change the password
			$query = "exec master.dbo.sp_password NULL, '$pass', '$old_login'";
			$res = mssql_query($query);
			if (!$res)
				psaerror('Unable to query: ' . $this->get_db_error());

			return true;
		}

		if ($this->userExistance($new_login)) {
			$this->setError_(lmsg('__user_already_exist', $login));
			return false;
		}

		if (!$this->userDel($old_login)) {
			$this->setError_('userDel() failed: ' . $this->getErrorMsg());
			return false;
		}

		if (!$this->userAdd($new_login, $pass)) {
			$errormsg = 'Unable to add user to the database: ' . $this->getErrorMsg();
			$this->userAdd($old_login, $pass);
			$this->setError_($errormsg);
			return false;
		}

		return true;
	}

	function userDel($login)
	{
		$query = "exec " . $this->name . ".dbo.sp_revokedbaccess '$login'";
		$res = mssql_query($query);
		if (!$res)
			psaerror('Unable to query: ' . $this->get_db_error());

		$query = "exec master.dbo.sp_droplogin '$login'";
		$res = mssql_query($query);
		if (!$res)
			psaerror('Unable to query: ' . $this->get_db_error());

		return true;
	}

	/*
	We probably do not need this function, cause this functionality moved to domainmng utility
	I leave this text only for info, couse there is no this code in CVS

	function userAccessEnable($login)
	{
		$query = "exec master.dbo.sp_addrolemember 'db_accessadmin', '$login'";
		$res = mssql_query($query);
		if (!$res)
			psaerror('Unable to query: ' . $this->get_db_error());

		$query = "exec master.dbo.sp_droprolemember 'db_denydatareader', '$login'";
		$res = mssql_query($query);
		if (!$res)
			psaerror('Unable to query: ' . $this->get_db_error());

		$query = "exec master.dbo.sp_droprolemember 'db_denydatawriter', '$login'";
		$res = mssql_query($query);
		if (!$res)
			psaerror('Unable to query: ' . $this->get_db_error());

		return true;
	}
	*/

	function userAccessDisable($login)
	{
		// After changing these SQL queries, make the same changes in domainmng --turn-off utility	/kan
		$query = "exec master.dbo.sp_droprolemember 'db_accessadmin', '$login'";
		$res = mssql_query($query);
		if (!$res)
			psaerror('Unable to query: ' . $this->get_db_error());

		$query = "exec master.dbo.sp_addrolemember 'db_denydatareader', '$login'";
		$res = mssql_query($query);
		if (!$res)
			psaerror('Unable to query: ' . $this->get_db_error());

		$query = "exec master.dbo.sp_addrolemember 'db_denydatawriter', '$login'";
		$res = mssql_query($query);
		if (!$res)
			psaerror('Unable to query: ' . $this->get_db_error());

		return true;
	}

	function dbExistance($db_name)
	{
		$query = "SELECT name FROM master.dbo.sysdatabases WHERE name='$db_name'";
		$res = mssql_query($query);
		if (!$res)
			psaerror('Unable to query: ' . $this->get_db_error());

		$ret_val = (mssql_num_rows($res) != 0);
		mssql_free_result($res);

		return $ret_val;
	}

	function userExistance($login)
	{
		$query = "SELECT name FROM master.dbo.sysusers WHERE name='$login'";
		$res = mssql_query($query);
		if (!$res)
			psaerror('Unable to query: ' . $this->get_db_error());

		$ret_val = (mssql_num_rows($res) != 0);
		mssql_free_result($res);

		return $ret_val;
	}

	function getSize()
	{
		$query = "SELECT sum(size) FROM " . $this->name . ".dbo.sysfiles";
		$res = mssql_query($query);
		if (!$res)
			psaerror('Unable to query: ' . $this->get_db_error());

		if (!(list($size) = mssql_fetch_array($res))) {
			$this->setError_('Unable to define database size: ' . $this->get_db_error());
			mssql_free_result($res);
			return false;
		}
		mssql_free_result($res);

		return $size;
	}

	function changeLogin($new_login, $old_login, $new_passwd)
	{
		psaerror('There is need to implement utility for creating/modification users.');
	}

	function get_db_error()
	{
		return mssql_get_last_message();
	}
}
?>
