<?php
include_once('class.errHandler.php');

class Database_postgresql extends errHandler
{
	var $db_type	= DB_POSTGRESQL;
	var $db_data;					// data from get_db_list() function
	var $name		= '';
	var $host		= 'localhost';
	var $connection	= false;
	var $isRunning;

	function Database_postgresql($db_name)
	{
		if (empty($db_name)) {
			$this->setError_('Database name is empty.');
			return;
		}

		$this->name = $db_name;

		include_once('cmd_server.php3');
		$db_list =& get_db_list();
		$this->db_data = $db_list[$this->db_type];

		/// Check for DATABASE is installed
		include_once('class.ComponentsChecker.php');

		$components_checker = new ComponentsChecker();
		if ($components_checker->error()) {
			$this->setError_('ComponentsChecker() constructor failed: ' . $components_checker->getErrorMsg());
			return false;
		}

		$isInstalled = $components_checker->isPostgreSQLInstalled();
		if ($components_checker->error()) {
			$this->setError_('isPackageInstalled() failed: ' . $components_checker->getErrorMsg());
			return false;
		}
		if (!$isInstalled) {
			$this->setError_(lmsg('__database_not_installed', $this->db_data['name']));
			return false;
		}

		/// Check for DATABASE is runnig
		include_once('class.ServiceControl.php');
		$service =& ServiceControlMaker();

		$this->isRunning = $service->getServiceStatus($this->db_type);
		if ($service->error()) {
			$this->setError_('getServiceStatus() failed: ' . $service->getErrorMsg());
			return false;
		}
		if (!$this->isRunning) {
			$this->setError_(lmsg('__database_not_run', $this->db_data['name']));
			return false;
		}

		if (!$this->connect_()) {
			$err_str = $this->getErrorMsg();
			/// This check not worked - pg_last_error() not return error report
			if (LOGIN_FAILED != $err_str)
				$this->setError_('Unable to connect to database: ' . $err_str);

			return false;
		}

		return;
	}

	function connect_()
	{
		if (false != $this->connection)
			return $this->connection;

		$login	= get_param($this->db_type . DB_ADMIN_LOGIN_SUFFIX);
		$passwd	= get_param($this->db_type . DB_ADMIN_PASSWD_SUFFIX);

		if (empty($login)) {
			$this->setError_(lmsg('__database_not_activated', $this->db_data['name']));
			return false;
		}

		// VZA use remote connect in VZPlesk
		require_once('virtuozzo/vz_func.php');
		if (is_vzplesk_mode()) {
			$host = getenv('PSA_VE_IP');
			$this->connection = pg_connect("user=$login password=$passwd host=$host dbname=template1");
		} else {
			///	Host connect
			//	$this->connection = pg_connect("user=$login password=$passwd host=" . $this->host . " dbname=template1");
			///	Local connect
			$this->connection = pg_connect("user=$login password=$passwd dbname=template1");
		}
		if (!$this->connection) {
			$err_str = isset($php_errormsg)? $php_errormsg: "Unable to connect to PostgreSQL server: ";
			$this->setError_($err_str);
			return false;
		}

		return true;
	}

	function create()
	{
		if ($this->dbExistance($this->name)) {
			$this->setError_(lmsg('__db_already_exist', $this->name));
			return false;
		}

		if (!smart_exec('pg_manage', array('add_db', $this->name))) {
			global $plesk_errormsg;
			$this->setError_('Unable to add file for db users list: ' . $plesk_errormsg);
			return false;
		}

		$res = pg_query('CREATE DATABASE "' . $this->name . '" WITH ENCODING=\'UNICODE\'');
		if (!$res) {
			$this->setError_('Unable to query: ' . $this->get_db_error());
			return false;
		}	

		return true;
	}

	function remove()
	{
		if (!smart_exec('pg_manage', array('rm_db', $this->name))) {
			global $plesk_errormsg;
			$this->setError_('Unable to remove file for db users list: ' . $plesk_errormsg);
			return false;
		}

		$res = pg_query('DROP DATABASE "' . $this->name . '"');
		
		if (!$res) {
			$this->setError_('Unable to query: ' . $this->get_db_error());
			return false;
		}

		return true;
	}

	function userAdd($login, $pass)
	{
		if ($this->userExistance($login)) {
			$this->setError_(lmsg('__user_already_exist', $login));
			return false;
		}

		if (!smart_exec('pg_manage', array('add_db_usr', $this->name, $login))) {
			global $plesk_errormsg;

			$this->setError_('Unable to remove file for db users list: ' . $plesk_errormsg);
			return false;
		}

		$res = pg_query("CREATE USER \"$login\" WITH PASSWORD '$pass' NOCREATEDB NOCREATEUSER");
		if (!$res)
			psaerror('Unable to query: ' . $this->get_db_error());

		return true;
	}

	/**
	 *	Parameters - 3 arrays:
	 *	$logins = array($old_login => $new_login);
	 *	$pass
	 */
	function userMod(&$logins, $pass)
	{
		if (!(list($old_login, $new_login) = each($logins)))
			psaerror('Unable to get user variables.');

		/// login changed - check if new user already exists in pg db
		if ($new_login != $old_login) {

			if ($this->userExistance($new_login)) {
				$this->setError_(lmsg('__user_already_exist', $new_login));
				return false;
			}

			if (!smart_exec('pg_manage', array('rm_db_usr', $this->name, $old_login))) {
				global $plesk_errormsg;
				$this->setError_('Unable to remove file for db users list: ' . $plesk_errormsg);
				return false;
			}

			if (!smart_exec('pg_manage', array('add_db_usr', $this->name, $new_login))) {
				global $plesk_errormsg;
				$this->setError_('Unable to remove file for db users list: ' . $plesk_errormsg);
				return false;
			}

			$res = pg_query("update pg_shadow set usename='$new_login', passwd='$pass' where usename='$old_login'");
			if (!$res)
				psaerror('Unable to query: ' . $this->get_db_error());

			return true;
		}

		$res = pg_query("ALTER USER \"$new_login\" WITH PASSWORD '$pass'");
		if (!$res) {
			$this->setError_('Unable to query: ' . $this->get_db_error());
			return false;
		}

		return true;
	}

	function userDel($login)
	{
		if (!smart_exec('pg_manage', array('rm_db_usr', $this->name, $login))) {
			global $plesk_errormsg;
			$this->setError_('Unable to remove file for db users list: ' . $plesk_errormsg);
			return false;
		}

		// just remove the user
		$res = pg_query("DROP USER \"$login\"");
		if (!$res)
			psaerror('Unable to query: ' . $this->get_db_error());

		return true;
	}

	function userAccessDisable($login)
	{
		$res = pg_query("ALTER USER \"$login\" VALID UNTIL '01 Jan 1970'");
		if (!$res)
			psaerror('Unable to query: ' . $this->get_db_error());

		return true;
	}

	function dbExistance($db_name)
	{
		$res = pg_query("SELECT * FROM pg_database WHERE datname='$db_name'");
		if (!$res)
			psaerror('Unable to query: ' . $this->get_db_error());

		$ret_val = (pg_numrows($res) != 0);
		pg_freeresult($res);

		return $ret_val;
	}

	function userExistance($login)
	{
		$res = pg_query("SELECT * FROM pg_shadow WHERE usename='$login'");
		if (!$res)
			psaerror('Unable to query: ' . $this->get_db_error());

		$ret_val = (pg_numrows($res) != 0);
		pg_freeresult($res);

		return $ret_val;
	}

	function getSize()
	{
		$res = pg_query('select oid from pg_database where datname=\'' . $this->name . '\'');
		if (!$res)
			psaerror('Unable to query: ' . $this->get_db_error());

		if (!(list($db_oid) = pg_fetch_array($res))) {
			$this->setError_('Unable to get Database oid.');
			pg_freeresult($res);
			return 0;
		}
		pg_freeresult($res);

		$params = array(POSTGRES_ROOT . '/base/' . $db_oid);
		$ret = util_exec('get_dir_size', $params, 'lst');
		if (!$ret) {
			global $plesk_errormsg;
			$this->setError_('Unable to define database size: ' . $plesk_errormsg);
			return 0;
		}

		return $ret[0];
	}

	function changeLogin($new_login, $old_login, $new_passwd)
	{
		$exec_array = (empty($old_login)) ?
						array('create_user', $new_login) :
						array('change_user', $old_login, $new_login);

		$ret_val = true;
		putenv ('PSA_PASSWORD='.$new_passwd);
		if (!smart_exec('pg_manage', $exec_array)) {
			global $plesk_errormsg;
			$plesk_errormsg = 'Error while execute pg_manage: ' . $plesk_errormsg;
			if (isset($this) && is_object($this))
				$this->setError_($plesk_errormsg);
			$ret_val = false;
		}

		putenv('PSA_PASSWORD=');
		return $ret_val;
	}

	function changePassword($login, $old_passwd, $passwd)
	{
		$ret_val = true;

		if (demo_version())
			return $ret_val;

		// just change the password
		$res = pg_query("ALTER USER \"$login\" WITH PASSWORD '$passwd'");
		if (!$res) {	/// Try to execute utility if DB engine stopped

			putenv ('PSA_PASSWORD=' . $passwd);
			if (!smart_exec('pg_manage', array('change_pass', $login))) {
				global $plesk_errormsg;
				$plesk_errormsg = 'Error while execute pg_manage: ' . $plesk_errormsg;
				$ret_val = false;
			}
			putenv('PSA_PASSWORD=');

		}

		return $ret_val;
	}

	function removeLogin($login)
	{
		if (!smart_exec('pg_manage', array('remove_user', $login))) {
			global $plesk_errormsg;
			$plesk_errormsg = 'Error while execute pg_manage: ' . $plesk_errormsg;
			return false;
		}

		return true;
	}

	function get_db_error()
	{
		return is_resource($this->connection) && get_resource_type($this->connection) == "pgsql link"? pg_last_error($this->connection): false;
	}
}
?>
