#!/bin/sh
# Copyright (c) 2002 by SWsoft Inc.
# All rights reserved
#

p_echo()
{
	echo "$*" >> "$product_log" 2>&1
	echo "$*"
}

pnnl_echo()
{
	if [ -z $necho_defined ]; then
		# set up echo
		case "`echo 'x\c'`" in
    		'x\c')
				echo="echo -n"
				nnl=
			;;
			x)
				echo="echo"
				nnl="\c"
			;;
			*)
				echo "ERROR: unable to set up echo."
			;;
		esac
		necho_defined=true
	fi

	$echo "$*${nnl}" >> "$product_log" 2>&1
	$echo "$*${nnl}"
}

die()
{
	printf "\a\a"
	p_echo
	p_echo "ERROR while trying to $*"
	p_echo "Check the error reason, fix and try again"
	p_echo
	p_echo "Aborting..."
	p_echo

	exit 1
}

err()
{
	p_echo
	p_echo "ERROR!"
	p_echo "Check the error reason, fix and try again"
	p_echo
	p_echo "Exiting..."
	p_echo

	exit 1
}

echo_try()
{
	msg="$*"

	pnnl_echo " Trying to $msg... "
}

suc()
{
	p_echo "done"
}

test_for_root()
{
	my_id="`id`"
	case "$my_id" in
		uid=0\(root\)*)
			;;
		*)	p_echo "$0: This script must be run as root"
			p_echo "Became a root and then run this script"
			p_echo
			exit 1
			;;
	esac
}

chk_version()
{
	if [ -d "$product_root" ]; then
		product_real_ver="`cat $product_root/version | awk '{print $1}'`"
		case "$product_real_ver" in
	    [67]*)
			;;
	    *)	p_echo
			p_echo "You have $product_bb version $product_real_ver"
			p_echo "In order for this script to work properly, please ensure that the version"
			p_echo "of the $product_bb that you're attempting to modify is $product_version."
	    	p_echo "OK. Goodbye! See you later"
	    	p_echo
	    	exit 0
			;;
	    esac
	fi

}

get_etc_conf()
{
	if [ ! -f $config ]; then
		p_echo "ERROR: Unable to open $config file."
		exit 3
	fi

	product_root=`cat $config | grep PRODUCT_ROOT_D | awk '{print $2}'`
	if [ -z "$product_root" ]; then
		p_echo "ERROR: Unable to define $product root directory."
		exit 3
	fi

	rc_dir=`cat $config | grep PRODUCT_RC_D | awk '{print $2}'`
	if [ -z "$rc_dir" ]; then
		rc_dir=$product_root/rc.d
	fi

	mysql_bin_dir=`cat $config | grep MYSQL_BIN_D | awk '{print $2}'`
	if [ -z "$mysql_bin_dir" ]; then
		mysql_bin_dir=$product_root/mysql/bin
	fi
}

get_pid()
{
	if [ ! -z "$PID" ]; then
		return
	fi

	proc_name="$1"

	case "$machine" in
	solaris)
		PID=`ps -ef | grep "$proc_name" | grep -v grep | awk '{print $2}'`
	;;
	*)
		PID=`ps -axww | awk '$5 ~ "'$proc_name']*$" {print $1}'`
	;;
	esac
}

main_screen()
{
clear

p_echo
p_echo	"		Skin management utility"
p_echo
p_echo	"	[1] List installed skins"
p_echo	"	[2] Remove installed skin"
p_echo	"	[3] Exit"
p_echo
pnnl_echo	"Enter action number: "

}

hit_enter()
{
	local i

	echo
	echo -n "Hit 'Enter' to continue... "
	read i
}

start_mysql()
{
	get_pid "mysqld"
	if [ -z "$PID" ]; then
		inten="start MySQL server"
		echo_try $inten
		$rc_dir/mysqld start >> $product_log 2>&1 &&
		suc || die $inten
		sleep 2
	fi
}

stop_mysql()
{
	if [ -z "$PID" ]; then
		inten="stop MySQL server"
		echo_try $inten
		$rc_dir/mysqld stop >> $product_log 2>&1 &&
		suc || die $inten
		sleep 2
	fi
}

list_skins()
{

	start_mysql

	echo "select id,name from Skins" | $mysql
	retcode=$?

	if [ "X$retcode" != "X0" ]; then
		die "Can't extract list of skins installed"
	fi

	hit_enter
}

# Check if skin with given id exists. 
# Returns number of skins with given id (1 or 0 most of all)
check_skin()
{
	if [ -z "$1" ]; then
		return 0
	fi

	return `echo "SELECT COUNT(*) FROM Skins WHERE id='$1'" | $mysql`
}

# Determine skin to replace the original
replace_skin()
{
	local new_skin_id old_skin_id res

	if [ -z "$1" ]; then
		return 0
	fi

	old_skin_id="$1"

	echo "Allowed skins are:"
	echo
	echo "SELECT id,name FROM Skins WHERE id<>'$1'" | $mysql
	echo

	echo -n "Select skin ID to replace deleting skin: "
	read new_skin_id

	if [ "X$old_skin_id" = "X$new_skin_id" ]; then
		echo "Select another skin id"
		return 0
	fi

	# Check skin id for correctness

	check_skin $new_skin_id
	if [ "X$?" = "X0" ]; then
		echo "Wrong skin id (no such skin)"
		return 0
	fi

	return $new_skin_id
}

remove_skin()
{
	local new_skin_id new_skin_name new_skin_place
	local skin_id     skin_name     skin_place
	local skin_used   skin_admin    skin_default

	local query res confirmation

	# Start MySQL if it's not running

	start_mysql

	# Check that skin is not only skin in a system

	res=`echo "SELECT COUNT(*) FROM Skins" | $mysql`

	case "$res" in
	"X1")
		echo "Can't delete the only skin in a system because it will breaks"
		echo "Plesk's functionality. At least one skin should be installed."
		hit_enter
		return
	;;
	"X0")
		echo "Seems like your installation of Plesk is corrupted."
		echo "Skin manager can't find skins. You should add at least one skin"
		echo "or contact Plesk's support."
		hit_enter
		return
	;;
	esac

	# Determine what skin should be deleted

	echo -n "Enter id of the skin to remove: "
	read skin_id

	# Check skin id for correctness

	check_skin $skin_id
	if [ "X$?" = "X0" ]; then
		echo "Wrong skin id (no such skin)"
		hit_enter
		return
	fi

	#
	# Confirm deletion of the skin
	#

	# Extract skin information

	skin_name=`echo "SELECT name  FROM Skins WHERE id='$skin_id'" | $mysql`
	skin_place=`echo "SELECT place FROM Skins WHERE id='$skin_id'" | $mysql`
	skin_place="$dist_dir/admin/htdocs$skin_place"

	# Look if this skin was used by other users

	query="	SELECT COUNT(*) FROM cl_param \
			WHERE param='skin_id' AND val='$skin_id'"

	skin_used=`echo $query | $mysql`

	# Look if this skin was used by admin

	query="	SELECT COUNT(*) FROM misc \
			WHERE param='admin_skin_id' AND val='$skin_id'"

	skin_admin=`echo $query | $mysql`

	if [ "X$skin_admin" != "X0" ]; then
		let skin_used=$skin_used+1
	fi

	# Look if this skin was used as default

	query="	SELECT COUNT(*) FROM misc \
			WHERE param='def_skin_id' AND val='$skin_id'"

	skin_default=`echo $query | $mysql`

	#
	# Alert if this skin is used and force user to enter new skin ID for 
	# replacement
	#

	new_skin_id=0

	if [ "X$skin_used" != "X0" ] || [ "X$skin_default" != "X0" ] ; then

		if [ "X$skin_default" != "X0" ]; then
			echo
			echo "This skin is used as default"
		fi

		echo
		if [ "X$skin_used" = "X1" ]; then
			echo "There is 1 user which uses this PSA skin"
		else
			echo "There are $skin_used users who use this PSA skin"
		fi

		echo
		echo "You should select skin to replace deleting one"

		replace_skin $skin_id
		new_skin_id="$?"
		if [ "X$new_skin_id" = "X0" ]; then
			hit_enter
			return
		fi
	fi

	echo "You are trying to remove skin \"$skin_name\" placed in"
	echo "\"$skin_place\" directory"

	if [ "X$new_skin_id" != "X0" ]; then

		# Extract skin information

		new_skin_name=`echo "SELECT name  FROM Skins WHERE id='$new_skin_id'" | $mysql`
		new_skin_place=`echo "SELECT place FROM Skins WHERE id='$new_skin_id'" | $mysql`
		new_skin_place="$dist_dir/admin/htdocs$new_skin_place"

		# Print skin information

		echo "And replace it with skin \"$new_skin_name\" placed in"
		echo "\"$new_skin_place\" directory"
	fi

	echo -n "Is this correct? (y/n) "
	read confirmation

	confirmation=`echo "$confirmation" | tr '[:lower:]' '[:upper:]'`

	if [ "X$confirmation" = "XN" ]; then
		echo "Canceled..."
		hit_enter
		return
	fi

	if [ "X$confirmation" != "XY" ]; then
		echo "Answer please 'y' or 'n'"
		hit_enter
		return
	fi

	# Deletion confirmed...

	# Replace skin id in database if $new_skin_id is not empty

	if [ "X$new_skin_id" != "X0" ]; then

		# Replace client's skins
		query="	UPDATE cl_param SET val='$new_skin_id' \
				WHERE param='skin_id' AND val='$skin_id'"

		echo "$query" | $mysql
		if [ "X$?" != "X0" ]; then
			echo "Error occured during skin replacement in database"
			hit_enter
			return
		fi

		# Replace default and admin's skins
		query="UPDATE misc SET val='$new_skin_id' WHERE \
		(param='admin_skin_id' OR param='def_skin_id') AND val='$skin_id'"

		echo "$query" | $mysql
		if [ "X$?" != "X0" ]; then
			echo "Error occured during skin replacement in database"
			hit_enter
			return
		fi

	fi

	# Remove from database
	echo "DELETE FROM Skins WHERE id='$skin_id'" | $mysql
	if [ "X$?" != "X0" ]; then
		echo "Can't delete skin from database."
		hit_enter
		return
	fi

	# Remove from disk
	rm -rf $skin_place

	echo "Skin successfully deleted"
	hit_enter
}

TARGET_OS="`uname -a`"
case "$TARGET_OS" in
	FreeBSD*i386)
		machine="BSD"
		;;
	Linux*2.?.*i?86*| \
	Linux*2.?.*x86_64*)
   			machine="linux"
		;;
	*)	p_echo "Not supported OS for patch"
		exit 1
		;;
esac


PATH=/sbin:/bin:/usr/sbin:/usr/bin:/usr/local/sbin:/usr/local/bin
export PATH

my_name_0=`pwd`
my_name_1=`basename ""$0""`
my_name_2=`echo ""$0""|sed -e "s/^\.\///"`
case "$?" in
	0)
		my_name="$my_name_2"
	;;
	1)
		my_name="$my_name_0"/"$my_name_2"
	;;
    *)
		err
	;;
esac

###!!!!!! GLOBAL VARIABLES !!!!!###
product="psa"
product_bb="Plesk"

support_email=support@plesk.com
sales_email=sales@plesk.com

###!!!!!! end GLOBAL VARIABLES !!!!!###

product_log="/tmp/${my_name_1}.log"
config="/etc/$product/$product.conf"

test_for_root
get_etc_conf

dist_dir="$product_root"
admin_user="${product}adm"
admin_group="${product}adm"
admin_passwd="`cat /etc/$product/.psa.shadow`"
mysql="$mysql_bin_dir/mysql -N -uadmin -p$admin_passwd ${product}"

echo >> $product_log #initializing log
echo "START LOGGING: `date`" >> $product_log

chk_version

while : ; do
	main_screen

	read answer
	if [ "$answer" = "1" ] ; then
		list_skins
   	elif [ "$answer" = "2" ] ; then
   		remove_skin
   	elif [ "$answer" = "3" ] ; then
		clear
   		exit 0
   	fi

done

